@@ -4,18 +4,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
- 'ARFLAGS': 'rc',
+ 'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib64/python3.6',
- 'BLDLIBRARY': '-L. -lpython3.6m',
- 'BLDSHARED': 'gcc -pthread -shared -Wl,-z,relro  -Wl,-z,now '
-              '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g -Wl,-z,relro  '
-              '-Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  '
-              '-flto -fuse-linker-plugin -ffat-lto-objects '
-              '-flto-partition=none',
+ 'BINLIBDEST': '/usr/lib64/python3.7',
+ 'BLDLIBRARY': '-L. -lpython3.7m',
+ 'BLDSHARED': 'gcc -pthread -shared -Wl,-z,relro   -Wl,-z,now '
+              '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
+              '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-redhat-linux-gnu',
@@ -28,8 +26,16 @@ build_time_vars = {'ABIFLAGS': 'm',
            '-fstack-protector-strong -grecord-gcc-switches '
            '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
            '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 -mtune=generic '
-           '-fasynchronous-unwind-tables -fstack-clash-protection -mcet '
-           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv',
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2 -g -pipe -Wall '
+           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+           '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
+           '-grecord-gcc-switches '
+           '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+           '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 -mtune=generic '
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -flto '
+           '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
@@ -41,14 +47,19 @@ build_time_vars = {'ABIFLAGS': 'm',
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
                      '-mtune=generic -fasynchronous-unwind-tables '
-                     '-fstack-clash-protection -mcet -fcf-protection '
-                     '-D_GNU_SOURCE -fPIC -fwrapv',
+                     '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
+                     '-fPIC -fwrapv  -flto -fuse-linker-plugin '
+                     '-ffat-lto-objects -flto-partition=none',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
-                            '-Wno-missing-field-initializers',
+                            '-Wno-missing-field-initializers '
+                            '-Wno-cast-function-type '
+                            '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-z,relro  -Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g',
+ 'CONFIGURE_LDFLAGS': '-Wl,-z,relro   -Wl,-z,now '
+                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
+                      '-fuse-linker-plugin -ffat-lto-objects '
+                      '-flto-partition=none',
  'CONFIG_ARGS': "'--build=x86_64-redhat-linux-gnu' "
                 "'--host=x86_64-redhat-linux-gnu' '--program-prefix=' "
                 "'--disable-dependency-tracking' '--prefix=/usr' "
@@ -72,32 +83,32 @@ build_time_vars = {'ABIFLAGS': 'm',
                 '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                 '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
                 '-mtune=generic -fasynchronous-unwind-tables '
-                '-fstack-clash-protection -mcet -fcf-protection -D_GNU_SOURCE '
-                "-fPIC -fwrapv ' 'LDFLAGS=-Wl,-z,relro  -Wl,-z,now "
+                '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
+                "-fwrapv ' 'LDFLAGS=-Wl,-z,relro   -Wl,-z,now "
                 "-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g ' "
                 "'CPPFLAGS=' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.6m',
- 'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.6.5/build/optimized/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.6.5/build/optimized/lcov-report',
+ 'CONFINCLUDEPY': '/usr/include/python3.7m',
+ 'COREPYTHONPATH': '',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.7.0/build/optimized/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.7.0/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.6.5/Include',
+             '-I/builddir/build/BUILD/Python-3.7.0/Include',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.6 '
-             '/usr/lib64/python3.6/lib-dynload',
- 'DESTLIB': '/usr/lib64/python3.6',
+ 'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.7 '
+             '/usr/lib64/python3.7/lib-dynload',
+ 'DESTLIB': '/usr/lib64/python3.7',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib64/python3.6/lib-dynload',
+ 'DESTSHARED': '/usr/lib64/python3.7/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+ 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+ 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
               'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
@@ -113,9 +124,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-36m-x86_64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-37m-x86_64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -179,6 +189,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
  'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
  'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
@@ -305,6 +316,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
+ 'HAVE_LINUX_VM_SOCKETS_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -313,7 +325,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -339,12 +350,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_POSIX_SPAWN': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PREADV': 1,
+ 'HAVE_PREADV2': 1,
  'HAVE_PRLIMIT': 1,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
+ 'HAVE_PTHREAD_GETCPUCLOCKID': 1,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
@@ -352,13 +366,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_PWRITEV': 1,
+ 'HAVE_PWRITEV2': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
@@ -373,7 +388,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
- 'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -399,6 +413,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SHADOW_H': 1,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGINFO_T_SI_BAND': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
  'HAVE_SIGPENDING': 1,
@@ -500,6 +515,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UUID_CREATE': 0,
+ 'HAVE_UUID_ENC_BE': 0,
+ 'HAVE_UUID_GENERATE_TIME_SAFE': 1,
+ 'HAVE_UUID_H': 0,
+ 'HAVE_UUID_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -511,43 +531,42 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
+ 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-redhat-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include  /usr/include/python3.6m',
+ 'INCLDIRSTOMAKE': '/usr/include  /usr/include/python3.7m',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.6m',
+ 'INCLUDEPY': '/usr/include/python3.7m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.6m.so.1.0',
+ 'INSTSONAME': 'libpython3.7m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-Wl,-z,relro  -Wl,-z,now '
-            '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g -Wl,-z,relro  '
-            '-Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  '
-            '-flto -fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
+ 'LDFLAGS': '-Wl,-z,relro   -Wl,-z,now '
+            '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
+            '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.6m.so',
+ 'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -Wl,-z,relro  -Wl,-z,now '
-             '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g -Wl,-z,relro  '
-             '-Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  '
-             '-flto -fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
- 'LDVERSION': '3.6m',
+ 'LDSHARED': 'gcc -pthread -shared -Wl,-z,relro   -Wl,-z,now '
+             '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
+             '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
+ 'LDVERSION': '3.7m',
  'LIBC': '',
- 'LIBDEST': '/usr/lib64/python3.6',
+ 'LIBDEST': '/usr/lib64/python3.7',
  'LIBDIR': '/usr/lib64',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib64/pkgconfig',
- 'LIBPL': '/usr/lib64/python3.6/config-3.6m-x86_64-linux-gnu',
- 'LIBRARY': 'libpython3.6m.a',
+ 'LIBPL': '/usr/lib64/python3.7/config-3.7m-x86_64-linux-gnu',
+ 'LIBRARY': 'libpython3.7m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lpthread -ldl  -lutil',
@@ -562,46 +581,50 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'linux',
- 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib64/python3.6',
+ 'MACHDESTLIB': '/usr/lib64/python3.7',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.6.5/Modules/makesetup',
+ 'MAJOR_IN_SYSMACROS': 1,
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.7.0/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
+                   '_operator  _collections  _abc  itertools  atexit  _signal  '
+                   '_stat  time  _thread  _locale  _io  zipimport  '
+                   'faulthandler  _tracemalloc  _symtable  xxsubtype',
+ 'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools '
-             '_operator _collections itertools atexit _signal _stat time '
-             '_locale _io zipimport faulthandler _tracemalloc _symtable '
-             'xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  '
-            'Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  '
-            'Modules/_codecsmodule.o  Modules/_weakref.o  '
-            'Modules/_functoolsmodule.o  Modules/_operator.o  '
-            'Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  '
+ 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/_abc.o  Modules/itertoolsmodule.o  '
             'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
-            'Modules/timemodule.o  Modules/_localemodule.o  '
-            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
-            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
-            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/timemodule.o  Modules/_threadmodule.o  '
+            'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
+            'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
+            'Modules/textio.o Modules/stringio.o  Modules/zipimport.o  '
+            'Modules/faulthandler.o  Modules/_tracemalloc.o '
+            'Modules/hashtable.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-linux-gnu\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
+ 'OPENSSL_INCLUDES': '',
+ 'OPENSSL_LDFLAGS': '',
+ 'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe -Wall '
         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
         '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
         '-grecord-gcc-switches -specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 -mtune=generic '
-        '-fasynchronous-unwind-tables -fstack-clash-protection -mcet '
-        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv',
+        '-fasynchronous-unwind-tables -fstack-clash-protection -fcf-protection '
+        '-D_GNU_SOURCE -fPIC -fwrapv',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -616,10 +639,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
- 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PY3LIBRARY': 'libpython3.so',
  'PYLONG_BITS_IN_DIGIT': 0,
@@ -628,9 +651,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':',
+ 'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3.6',
+ 'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
@@ -641,21 +664,28 @@ build_time_vars = {'ABIFLAGS': 'm',
               '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
               '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
               '-mtune=generic -fasynchronous-unwind-tables '
-              '-fstack-clash-protection -mcet -fcf-protection -D_GNU_SOURCE '
-              '-fPIC -fwrapv',
+              '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
+              '-fwrapv -O2 -g -pipe -Wall -Werror=format-security '
+              '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+              '-fstack-protector-strong -grecord-gcc-switches '
+              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+              '-mtune=generic -fasynchronous-unwind-tables '
+              '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
+              '-fwrapv  -flto -fuse-linker-plugin -ffat-lto-objects '
+              '-flto-partition=none',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-O2 -g -pipe -Wall -Werror=format-security '
-                     '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
-                     '-fexceptions -fstack-protector-strong '
-                     '-grecord-gcc-switches '
+                     '-Wno-cast-function-type '
+                     '-Werror=implicit-function-declaration -O2 -g -pipe -Wall '
+                     '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                     '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                     '-fstack-protector-strong -grecord-gcc-switches '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
                      '-mtune=generic -fasynchronous-unwind-tables '
-                     '-fstack-clash-protection -mcet -fcf-protection '
-                     '-D_GNU_SOURCE -fPIC -fwrapv  -fprofile-use '
-                     '-fprofile-correction -flto -fuse-linker-plugin '
-                     '-ffat-lto-objects -flto-partition=none',
+                     '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
+                     '-fPIC -fwrapv  -fprofile-use -fprofile-correction',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe '
@@ -665,45 +695,85 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
                    '-mtune=generic -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -mcet -fcf-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -O2 -g -pipe -Wall '
+                   '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
+                   '-fPIC -fwrapv -O2 -g -pipe -Wall -Werror=format-security '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
+                   '-fexceptions -fstack-protector-strong '
+                   '-grecord-gcc-switches '
+                   '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                   '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+                   '-mtune=generic -fasynchronous-unwind-tables '
+                   '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
+                   '-fPIC -fwrapv  -flto -fuse-linker-plugin -ffat-lto-objects '
+                   '-flto-partition=none -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wno-cast-function-type '
+                   '-Werror=implicit-function-declaration -O2 -g -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
                    '-fstack-protector-strong -grecord-gcc-switches '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
                    '-mtune=generic -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -mcet -fcf-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv  -fprofile-use '
-                   '-fprofile-correction -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -flto-partition=none -IObjects -IInclude '
-                   '-IPython -I. -I/builddir/build/BUILD/Python-3.6.5/Include  '
+                   '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
+                   '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
+                   '-IObjects -IInclude -IPython -I. '
+                   '-I/builddir/build/BUILD/Python-3.7.0/Include '
                    '-DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.6.5/Include',
+                '-I/builddir/build/BUILD/Python-3.7.0/Include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-z,relro  -Wl,-z,now '
-               '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g -Wl,-z,relro  '
-               '-Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  '
-               '-flto -fuse-linker-plugin -ffat-lto-objects '
-               '-flto-partition=none',
+ 'PY_LDFLAGS': '-Wl,-z,relro   -Wl,-z,now '
+               '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
+               '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe '
+                        '-Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                        '-fstack-protector-strong -grecord-gcc-switches '
+                        '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+                        '-mtune=generic -fasynchronous-unwind-tables '
+                        '-fstack-clash-protection -fcf-protection '
+                        '-D_GNU_SOURCE -fPIC -fwrapv -O2 -g -pipe -Wall '
+                        '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                        '-fstack-protector-strong -grecord-gcc-switches '
+                        '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+                        '-mtune=generic -fasynchronous-unwind-tables '
+                        '-fstack-clash-protection -fcf-protection '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -flto '
+                        '-fuse-linker-plugin -ffat-lto-objects '
+                        '-flto-partition=none -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
+                        '-Wno-cast-function-type '
+                        '-Werror=implicit-function-declaration -O2 -g -pipe '
+                        '-Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                        '-fstack-protector-strong -grecord-gcc-switches '
+                        '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+                        '-mtune=generic -fasynchronous-unwind-tables '
+                        '-fstack-clash-protection -fcf-protection '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -fprofile-use '
+                        '-fprofile-correction -IObjects -IInclude -IPython -I. '
+                        '-I/builddir/build/BUILD/Python-3.7.0/Include',
  'PY_WARN_ON_C_LOCALE': 1,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'RANLIB': 'ranlib',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.5/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.0/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '',
+ 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lpthread -ldl  -lutil',
  'SHLIB_SUFFIX': '.so',
@@ -718,6 +788,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
+ 'SIZEOF_PTHREAD_KEY_T': 4,
  'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 8,
@@ -726,9 +797,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36m-x86_64-linux-gnu',
+ 'SOABI': 'cpython-37m-x86_64-linux-gnu',
  'SRCDIRS': 'Parser Objects Python Modules Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.6.5/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.7.0/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -741,25 +812,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.5/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.0/build/optimized '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.5/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.0/build/optimized '
                './python /Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
- 'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.6 '
-                '/builddir/build/BUILD/Python-3.6.5/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.7 '
+                '/builddir/build/BUILD/Python-3.7.0/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'USE_INLINE': 1,
- 'VERSION': '3.6',
- 'VPATH': '/builddir/build/BUILD/Python-3.6.5',
- 'WANT_SIGFPE_HANDLER': 0,
+ 'VERSION': '3.7',
+ 'VPATH': '/builddir/build/BUILD/Python-3.7.0',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 1,
@@ -767,13 +835,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
- 'WITH_THREAD': 1,
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.6.5/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.6.5',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.7.0/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.7.0',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.6.5'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.7.0'}
